=======================
Salt Community Projects
=======================

This page contains links to Salt-related projects created by community members.
If you come across a useful project please add it to the list!

Hubblestack
===========
Hubble is a modular, open-source security compliance framework built on top of
SaltStack. The project provides on-demand profile-based auditing, real-time
security event notifications, automated remediation, alerting and reporting.

http://hubblestack.io/

alkali
======
alkali is a collections of SaltStack states and pillar data that provide just
the basics for provisioning Linux instances that may be built upon. alkali is
a starter kit of sorts, to help new users to SaltStack get up-and-running
quickly with the most commonly used, core packages.

https://github.com/zulily/alkali

buoyant
=======
buoyant leverages docker to provide an alternative to VM-centric SaltStack
development environments. buoyant containers may be spun up nearly instantly,
once an initial docker image has been built.

https://github.com/zulily/buoyant

Salt Sandbox
============
Salt Sandbox is a multi-VM Vagrant-based Salt development environment used
for creating and testing new Salt state modules outside of your production
environment. It's also a great way to learn firsthand about Salt and its
remote execution capabilities.

https://github.com/elasticdog/salt-sandbox

Salt Vagrant Demo
=================
A Salt Demo using Vagrant.

https://github.com/UtahDave/salt-vagrant-demo

